Class: ActiveRecord::Refined::AST::Ordering
- Defined in:
- lib/active_record/refined/ast.rb
Instance Attribute Summary collapse
-
#direction ⇒ Object
readonly
Returns the value of attribute direction.
-
#nulls ⇒ Object
readonly
Returns the value of attribute nulls.
-
#operand ⇒ Object
readonly
Returns the value of attribute operand.
Instance Method Summary collapse
-
#initialize(operand, direction, nulls = nil) ⇒ Ordering
constructor
A new instance of Ordering.
-
#nulls_first ⇒ Object
MySQL has no NULLS FIRST/LAST, but Arel emulates it there with a leading IS NULL ordering, so these are portable.
- #nulls_last ⇒ Object
- #to_arel(table, model) ⇒ Object
Methods inherited from Node
Constructor Details
#initialize(operand, direction, nulls = nil) ⇒ Ordering
Returns a new instance of Ordering.
1205 1206 1207 1208 1209 |
# File 'lib/active_record/refined/ast.rb', line 1205 def initialize(operand, direction, nulls = nil) @operand = operand @direction = direction @nulls = nulls end |
Instance Attribute Details
#direction ⇒ Object (readonly)
Returns the value of attribute direction.
1203 1204 1205 |
# File 'lib/active_record/refined/ast.rb', line 1203 def direction @direction end |
#nulls ⇒ Object (readonly)
Returns the value of attribute nulls.
1203 1204 1205 |
# File 'lib/active_record/refined/ast.rb', line 1203 def nulls @nulls end |
#operand ⇒ Object (readonly)
Returns the value of attribute operand.
1203 1204 1205 |
# File 'lib/active_record/refined/ast.rb', line 1203 def operand @operand end |
Instance Method Details
#nulls_first ⇒ Object
MySQL has no NULLS FIRST/LAST, but Arel emulates it there with a leading IS NULL ordering, so these are portable.
1213 1214 1215 |
# File 'lib/active_record/refined/ast.rb', line 1213 def nulls_first Ordering.new(operand, direction, :nulls_first) end |
#nulls_last ⇒ Object
1217 1218 1219 |
# File 'lib/active_record/refined/ast.rb', line 1217 def nulls_last Ordering.new(operand, direction, :nulls_last) end |
#to_arel(table, model) ⇒ Object
1221 1222 1223 1224 |
# File 'lib/active_record/refined/ast.rb', line 1221 def to_arel(table, model) ordering = to_arel_operand(operand, table, model).public_send(direction) nulls ? ordering.public_send(nulls) : ordering end |