Module: ActiveRecord::Refined::AST::Windowing
- Included in:
- Aggregate, Function, JsonAggregate
- Defined in:
- lib/active_record/refined/ast.rb
Overview
OVER, on the two things that can carry a window: an aggregate, and a function.
OVER, on the two things that can carry a window: an aggregate, and a function.