Module: ActiveRecord::Refined::AST::Arithmetics

Included in:
Aggregate, Arithmetic, Cast, Column, DatetimeValueFunction, Extract, Function, Value
Defined in:
lib/active_record/refined/ast.rb

Overview

Arithmetic builders shared by symbols, qualified columns and expressions. Imported into the Symbol refinement like Predications, so every method must be defined with def.

Instance Method Summary collapse

Instance Method Details

#*(other) ⇒ Object



185
186
187
# File 'lib/active_record/refined/ast.rb', line 185

def *(other)
  Arithmetic.new(self, :*, other)
end

#+(other) ⇒ Object



177
178
179
# File 'lib/active_record/refined/ast.rb', line 177

def +(other)
  Arithmetic.new(self, :+, other)
end

#-(other) ⇒ Object



181
182
183
# File 'lib/active_record/refined/ast.rb', line 181

def -(other)
  Arithmetic.new(self, :-, other)
end

#/(other) ⇒ Object



189
190
191
# File 'lib/active_record/refined/ast.rb', line 189

def /(other)
  Arithmetic.new(self, :/, other)
end