Class: ActiveRecord::Refined::AST::Ordering
- Defined in:
- lib/active_record/refined/ast.rb
Instance Attribute Summary collapse
-
#direction ⇒ Object
readonly
Returns the value of attribute direction.
-
#nulls ⇒ Object
readonly
Returns the value of attribute nulls.
-
#operand ⇒ Object
readonly
Returns the value of attribute operand.
Instance Method Summary collapse
-
#initialize(operand, direction, nulls = nil) ⇒ Ordering
constructor
A new instance of Ordering.
-
#nulls_first ⇒ Object
MySQL has no NULLS FIRST/LAST, but Arel emulates it there with a leading IS NULL ordering, so these are portable.
- #nulls_last ⇒ Object
- #to_arel(table) ⇒ Object
Methods inherited from Node
Constructor Details
#initialize(operand, direction, nulls = nil) ⇒ Ordering
Returns a new instance of Ordering.
379 380 381 382 383 |
# File 'lib/active_record/refined/ast.rb', line 379 def initialize(operand, direction, nulls = nil) @operand = operand @direction = direction @nulls = nulls end |
Instance Attribute Details
#direction ⇒ Object (readonly)
Returns the value of attribute direction.
377 378 379 |
# File 'lib/active_record/refined/ast.rb', line 377 def direction @direction end |
#nulls ⇒ Object (readonly)
Returns the value of attribute nulls.
377 378 379 |
# File 'lib/active_record/refined/ast.rb', line 377 def nulls @nulls end |
#operand ⇒ Object (readonly)
Returns the value of attribute operand.
377 378 379 |
# File 'lib/active_record/refined/ast.rb', line 377 def operand @operand end |
Instance Method Details
#nulls_first ⇒ Object
MySQL has no NULLS FIRST/LAST, but Arel emulates it there with a leading IS NULL ordering, so these are portable.
387 388 389 |
# File 'lib/active_record/refined/ast.rb', line 387 def nulls_first Ordering.new(operand, direction, :nulls_first) end |
#nulls_last ⇒ Object
391 392 393 |
# File 'lib/active_record/refined/ast.rb', line 391 def nulls_last Ordering.new(operand, direction, :nulls_last) end |
#to_arel(table) ⇒ Object
395 396 397 398 |
# File 'lib/active_record/refined/ast.rb', line 395 def to_arel(table) ordering = to_arel_operand(operand, table).public_send(direction) nulls ? ordering.public_send(nulls) : ordering end |